@@ -19,7 +19,7 @@ import confuse
 
 from .util.deprecation import deprecate_imports
 
-__version__ = "2.6.1"
+__version__ = "2.6.2"
 __author__ = "Adrian Sampson <adrian@radbox.org>"
 
 
@@ -37,11 +37,11 @@ class IncludeLazyConfig(confuse.LazyConfig):
     YAML files specified in an `include` setting.
     """
 
-    def read(self, user=True, defaults=True):
+    def read(self, user: bool = True, defaults: bool = True) -> None:
         super().read(user, defaults)
 
         try:
-            for view in self["include"]:
+            for view in self["include"].sequence():
                 self.set_file(view.as_filename())
         except confuse.NotFoundError:
             pass
