@@ -15,9 +15,6 @@
 """This module includes various helpers that provide fixtures, capture
 information or mock the environment.
 
-- The `control_stdin` and `capture_stdout` context managers allow one to
-  interact with the user interface.
-
 - `has_program` checks the presence of a command on the system.
 
 - The `ImportSessionFixture` allows one to run importer code while
@@ -38,12 +35,12 @@ from contextlib import contextmanager
 from dataclasses import dataclass
 from enum import Enum
 from functools import cached_property
-from io import StringIO
 from pathlib import Path
 from tempfile import gettempdir, mkdtemp, mkstemp
 from typing import Any, ClassVar
 from unittest.mock import patch
 
+import pytest
 import responses
 from mediafile import Image, MediaFile
 
@@ -83,41 +80,6 @@ def capture_log(logger="beets"):
         log.removeHandler(capture)
 
 
-@contextmanager
-def control_stdin(input=None):
-    """Sends ``input`` to stdin.
-
-    >>> with control_stdin('yes'):
-    ...     input()
-    'yes'
-    """
-    org = sys.stdin
-    sys.stdin = StringIO(input)
-    try:
-        yield sys.stdin
-    finally:
-        sys.stdin = org
-
-
-@contextmanager
-def capture_stdout():
-    """Save stdout in a StringIO.
-
-    >>> with capture_stdout() as output:
-    ...     print('spam')
-    ...
-    >>> output.getvalue()
-    'spam'
-    """
-    org = sys.stdout
-    sys.stdout = capture = StringIO()
-    try:
-        yield sys.stdout
-    finally:
-        sys.stdout = org
-        print(capture.getvalue())
-
-
 def has_program(cmd, args=["--version"]):
     """Returns `True` if `cmd` can be executed."""
     full_cmd = [cmd, *args]
@@ -163,21 +125,31 @@ NEEDS_REFLINK = unittest.skipUnless(
 )
 
 
-class IOMixin:
-    @cached_property
-    def io(self) -> _common.DummyIO:
-        return _common.DummyIO()
-
-    def setUp(self):
-        super().setUp()
-        self.io.install()
-
-    def tearDown(self):
-        super().tearDown()
-        self.io.restore()
+class RunMixin:
+    def run_command(self, *args, **kwargs):
+        """Run a beets command with an arbitrary amount of arguments. The
+        Library` defaults to `self.lib`, but can be overridden with
+        the keyword argument `lib`.
+        """
+        sys.argv = ["beet"]  # avoid leakage from test suite args
+        lib = None
+        if hasattr(self, "lib"):
+            lib = self.lib
+        lib = kwargs.get("lib", lib)
+        beets.ui._raw_main(list(args), lib)
 
 
-class TestHelper(ConfigMixin):
+@pytest.mark.usefixtures("io")
+class IOMixin(RunMixin):
+    io: _common.DummyIO
+
+    def run_with_output(self, *args):
+        self.io.getoutput()
+        self.run_command(*args)
+        return self.io.getoutput()
+
+
+class TestHelper(RunMixin, ConfigMixin):
     """Helper mixin for high-level cli and plugin tests.
 
     This mixin provides methods to isolate beets' global state provide
@@ -392,25 +364,6 @@ class TestHelper(ConfigMixin):
 
         return path
 
-    # Running beets commands
-
-    def run_command(self, *args, **kwargs):
-        """Run a beets command with an arbitrary amount of arguments. The
-        Library` defaults to `self.lib`, but can be overridden with
-        the keyword argument `lib`.
-        """
-        sys.argv = ["beet"]  # avoid leakage from test suite args
-        lib = None
-        if hasattr(self, "lib"):
-            lib = self.lib
-        lib = kwargs.get("lib", lib)
-        beets.ui._raw_main(list(args), lib)
-
-    def run_with_output(self, *args):
-        with capture_stdout() as out:
-            self.run_command(*args)
-        return out.getvalue()
-
     # Safe file operations
 
     def create_temp_dir(self, **kwargs) -> str:
@@ -758,10 +711,7 @@ class TerminalImportSessionFixture(TerminalImportSession):
 class TerminalImportMixin(IOMixin, ImportHelper):
     """Provides_a terminal importer for the import session."""
 
-    io: _common.DummyIO
-
     def _get_import_session(self, import_dir: bytes) -> importer.ImportSession:
-        self.io.install()
         return TerminalImportSessionFixture(
             self.lib,
             loghandler=None,
