@@ -56,36 +56,10 @@ FIELDS_TO_MB_KEYS = {
     "label": "label",
     "media": "format",
     "year": "date",
+    "tracks": "tracks",
+    "alias": "alias",
 }
 
-
-RELEASE_INCLUDES = [
-    "artists",
-    "media",
-    "recordings",
-    "release-groups",
-    "labels",
-    "artist-credits",
-    "aliases",
-    "recording-level-rels",
-    "work-rels",
-    "work-level-rels",
-    "artist-rels",
-    "isrcs",
-    "url-rels",
-    "release-rels",
-    "genres",
-    "tags",
-]
-
-TRACK_INCLUDES = [
-    "artists",
-    "aliases",
-    "isrcs",
-    "work-level-rels",
-    "artist-rels",
-]
-
 BROWSE_INCLUDES = [
     "artist-credits",
     "work-rels",
@@ -475,7 +449,7 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
             release["artist-credit"], include_join_phrase=False
         )
 
-        ntracks = sum(len(m["tracks"]) for m in release["media"])
+        ntracks = sum(len(m.get("tracks", [])) for m in release["media"])
 
         # The MusicBrainz API omits 'relations'
         # when the release has more than 500 tracks. So we use browse_recordings
@@ -487,14 +461,18 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
                 self._log.debug("Retrieving tracks starting at {}", i)
                 recording_list.extend(
                     self.mb_api.browse_recordings(
-                        release=release["id"], offset=i
+                        release=release["id"],
+                        limit=BROWSE_CHUNKSIZE,
+                        includes=BROWSE_INCLUDES,
+                        offset=i,
                     )
                 )
-            track_map = {r["id"]: r for r in recording_list}
+            recording_by_id = {r["id"]: r for r in recording_list}
             for medium in release["media"]:
-                for recording in medium["tracks"]:
-                    recording_info = track_map[recording["recording"]["id"]]
-                    recording["recording"] = recording_info
+                for track in medium["tracks"]:
+                    track["recording"] = recording_by_id[
+                        track["recording"]["id"]
+                    ]
 
         # Basic info.
         track_infos = []
@@ -506,7 +484,7 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
             if format in config["match"]["ignored_media"].as_str_seq():
                 continue
 
-            all_tracks = medium["tracks"]
+            all_tracks = medium.get("tracks", [])
             if (
                 "data-tracks" in medium
                 and not config["match"]["ignore_data_tracks"]
@@ -791,7 +769,7 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
         # A 404 error here is fine. e.g. re-importing a release that has
         # been deleted on MusicBrainz.
         try:
-            res = self.mb_api.get_release(albumid, includes=RELEASE_INCLUDES)
+            res = self.mb_api.get_release(albumid)
         except HTTPNotFoundError:
             self._log.debug("Release {} not found on MusicBrainz.", albumid)
             return None
@@ -807,9 +785,7 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
                     rel["type"] == "transl-tracklisting"
                     and rel["direction"] == "backward"
                 ):
-                    actual_res = self.mb_api.get_release(
-                        rel["release"]["id"], includes=RELEASE_INCLUDES
-                    )
+                    actual_res = self.mb_api.get_release(rel["release"]["id"])
 
         # release is potentially a pseudo release
         release = self.album_info(res)
@@ -832,8 +808,6 @@ class MusicBrainzPlugin(MusicBrainzAPIMixin, MetadataSourcePlugin):
             return None
 
         with suppress(HTTPNotFoundError):
-            return self.track_info(
-                self.mb_api.get_recording(trackid, includes=TRACK_INCLUDES)
-            )
+            return self.track_info(self.mb_api.get_recording(trackid))
 
         return None
